@@ -66,17 +66,12 @@ bool FdoConnector::GetPowerSaveStatus()
 
 void FdoConnector::Suspend()
 {
-    triggerSuspendSession(PowerButtonAction::SuspendToRam);
+    triggerSuspendSession(PowerButtonAction::Sleep);
 }
 
 void FdoConnector::Hibernate()
 {
-    triggerSuspendSession(PowerButtonAction::SuspendToDisk);
-}
-
-void FdoConnector::HybridSuspend()
-{
-    triggerSuspendSession(PowerButtonAction::SuspendHybrid);
+    triggerSuspendSession(PowerButtonAction::Hibernate);
 }
 
 bool FdoConnector::HasInhibit()
