@@ -1,36 +1,23 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
- *   Copyright (C) 2012 Lukáš Tinkl <ltinkl@redhat.com>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2010 Dario Freddi <drf@kde.org>
+ *   SPDX-FileCopyrightText: 2012 Lukáš Tinkl <ltinkl@redhat.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
+#pragma once
 
-#ifndef POWERDEVIL_POWERDEVILPOLICYAGENT_H
-#define POWERDEVIL_POWERDEVILPOLICYAGENT_H
-
-#include <QObject>
 #include <QHash>
-#include <QStringList>
+#include <QList>
+#include <QObject>
 #include <QPointer>
-#include <QVector>
+#include <QStringList>
 
 #include <QDBusContext>
 #include <QDBusUnixFileDescriptor>
 
+#include "powerdevilcore_export.h"
+
 class QDBusServiceWatcher;
 class QDBusInterface;
 
@@ -48,8 +35,7 @@ class OrgFreedesktopScreenSaverInterface;
 
 using InhibitionInfo = QPair<QString, QString>;
 
-struct LogindInhibition
-{
+struct LogindInhibition {
     QString what;
     QString who;
     QString why;
@@ -59,15 +45,13 @@ struct LogindInhibition
 
     bool operator==(const LogindInhibition &other) const
     {
-        return what == other.what && who == other.who && why == other.why && mode == other.mode
-                && pid == other.pid && uid == other.uid;
+        return what == other.what && who == other.who && why == other.why && mode == other.mode && pid == other.pid && uid == other.uid;
     }
 };
 
 namespace PowerDevil
 {
-
-class Q_DECL_EXPORT PolicyAgent : public QObject, protected QDBusContext
+class POWERDEVILCORE_EXPORT PolicyAgent : public QObject, protected QDBusContext
 {
     Q_OBJECT
     Q_DISABLE_COPY(PolicyAgent)
@@ -78,8 +62,7 @@ public:
     enum RequiredPolicy {
         None = 0,
         InterruptSession = 1,
-        ChangeProfile = 2,
-        ChangeScreenSettings = 4
+        ChangeScreenSettings = 4,
     };
     Q_DECLARE_FLAGS(RequiredPolicies, RequiredPolicy)
 
@@ -117,20 +100,18 @@ Q_SIGNALS:
     void screenLockerActiveChanged(bool active);
 
 private Q_SLOTS:
-    void onServiceUnregistered(const QString & serviceName);
-    void onSessionHandlerRegistered(const QString & serviceName);
-    void onSessionHandlerUnregistered(const QString & serviceName);
-    void onActiveSessionChanged(const QString & ifaceName, const QVariantMap & changedProps, const QStringList & invalidatedProps);
+    void onServiceUnregistered(const QString &serviceName);
+    void onSessionHandlerRegistered(const QString &serviceName);
+    void onSessionHandlerUnregistered(const QString &serviceName);
+    void onActiveSessionChanged(const QString &ifaceName, const QVariantMap &changedProps, const QStringList &invalidatedProps);
     void onActiveSessionChanged(const QString &activeSession);
 
     void onManagerPropertyChanged(const QString &ifaceName, const QVariantMap &changedProps, const QStringList &invalidatedProps);
 
 private:
-    explicit PolicyAgent(QObject* parent = nullptr);
+    explicit PolicyAgent(QObject *parent = nullptr);
 
     void init();
-    void startSessionInterruption();
-    void finishSessionInterruption();
 
     void addInhibitionTypeHelper(uint cookie, RequiredPolicies types);
 
@@ -145,39 +126,38 @@ private:
     bool m_screenLockerActive = false;
 
     // This function serves solely for fd.o connector
-    uint addInhibitionWithExplicitDBusService(uint types, const QString &appName,
-                                              const QString &reason, const QString &service);
+    uint addInhibitionWithExplicitDBusService(uint types, const QString &appName, const QString &reason, const QString &service);
 
     // used by systemd and ConsoleKit
-    QScopedPointer< QDBusInterface > m_managerIface;
+    QScopedPointer<QDBusInterface> m_managerIface;
 
     // systemd support
-    QString getNamedPathProperty(const QString & path, const QString & iface, const QString & prop) const;
+    QString getNamedPathProperty(const QString &path, const QString &iface, const QString &prop) const;
     bool m_sdAvailable;
     QString m_activeSessionPath;
-    QPointer< QDBusInterface > m_sdSessionInterface;
-    QPointer< QDBusInterface > m_sdSeatInterface;
+    QPointer<QDBusInterface> m_sdSessionInterface;
+    QPointer<QDBusInterface> m_sdSeatInterface;
     QDBusUnixFileDescriptor m_systemdInhibitFd;
 
     // ConsoleKit support
     bool m_ckAvailable;
-    QPointer< QDBusInterface > m_ckSessionInterface;
-    QPointer< QDBusInterface > m_ckSeatInterface;
+    QPointer<QDBusInterface> m_ckSessionInterface;
+    QPointer<QDBusInterface> m_ckSeatInterface;
     bool m_sessionIsBeingInterrupted;
 
-    QHash< uint, QPair< QString, QString > > m_cookieToAppName;
-    QHash< uint, QString > m_cookieToBusService;
-    QHash< RequiredPolicy, QList< uint > > m_typesToCookie;
+    QHash<uint, QPair<QString, QString>> m_cookieToAppName;
+    QHash<uint, QString> m_cookieToBusService;
+    QHash<RequiredPolicy, QList<uint>> m_typesToCookie;
 
     QHash<uint, LogindInhibition> m_logindInhibitions;
 
-    QVector<int> m_pendingInhibitions;
+    QList<int> m_pendingInhibitions;
 
     uint m_lastCookie;
 
-    QPointer< QDBusServiceWatcher > m_busWatcher;
-    QPointer< QDBusServiceWatcher > m_sdWatcher;
-    QPointer< QDBusServiceWatcher > m_ckWatcher;
+    QPointer<QDBusServiceWatcher> m_busWatcher;
+    QPointer<QDBusServiceWatcher> m_sdWatcher;
+    QPointer<QDBusServiceWatcher> m_ckWatcher;
 
     bool m_wasLastActiveSession;
 
@@ -186,5 +166,3 @@ private:
 };
 
 }
-
-#endif // POWERDEVIL_POWERDEVILPOLICYAGENT_H
